<h1>
  <img src="https://github.com/jpsca/jinjax/raw/main/docs/jinjax-logo.png" height="50" align="top">
</h1>

<p>
  <img alt="python: 3.11, 3.12, 3.13, 3.14" src="https://github.com/jpsca/jinjax/raw/main/docs/python.svg">
  <img alt="license: MIT" src="https://github.com/jpsca/jinjax/raw/main/docs/license.svg">
</p>

From chaos to clarity: The power of components in your server-side-rendered Python web app.

**Documentation:** https://jinjax.scaletti.dev/

Write server-side components as single Jinja template files.
Use them as HTML tags without doing any importing.
